@@ -1,6 +1,6 @@
 /* sdlgfx.c --- Additional Graphics functions for Guile SDL
  *
- * Copyright (C) 2003-2005, 2007-2009, 2011, 2013 Thien-Thi Nguyen
+ * Copyright (C) 2003-2005, 2007-2009, 2011, 2013, 2015 Thien-Thi Nguyen
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -13,7 +13,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #define GUILE_SDL_OPTIONAL_MODULE  1
@@ -58,7 +58,7 @@ DEFINE_STRUCT_AND_COPY_FUNC (s16, Sint16)
  * gfxPrimitives
  */
 
-#include "SDL_gfx/SDL_gfxPrimitives.h"
+#include "SDL_gfxPrimitives.h"
 
 
 PRIMPROC
@@ -682,7 +682,7 @@ Set the rotation for glyphs drawn by @code{draw-character} and
  * rotozoom
  */
 
-#include "SDL_gfx/SDL_rotozoom.h"
+#include "SDL_rotozoom.h"
 
 
 PRIMPROC
@@ -698,7 +698,7 @@ by @var{angle} degrees.  Optional third arg @var{zoom}
 fourth arg @var{smooth} turns on anti-aliasing.  */)
 {
 #define FUNC_NAME s_roto_zoom_surface
-  SDL_Surface *csurface, *new_surface;
+  SDL_Surface *csurface;
   double cangle = 0.0, czoom = 1.0;
 
   ASSERT_SURFACE (surface, 1);
@@ -708,9 +708,9 @@ fourth arg @var{smooth} turns on anti-aliasing.  */)
   IF_BOUND_ASSERT_DOUBLE_COPY (zoom, 3);
   UNBOUND_MEANS_FALSE (smooth);
 
-  new_surface = rotozoomSurface (csurface, cangle, czoom, NOT_FALSEP (smooth));
-
-  RETURN_NEW_SURFACE (new_surface);
+  RETURN_NEW_SURFACE
+    (rotozoomSurface (csurface, cangle, czoom,
+                      NOT_FALSEP (smooth)));
 #undef FUNC_NAME
 }
 
@@ -729,7 +729,7 @@ changes the size as well.  Optional fifth arg @var{smooth}
 turns on anti-aliasing.  */)
 {
 #define FUNC_NAME s_roto_zoom_surface_xy
-  SDL_Surface *csurface, *new_surface;
+  SDL_Surface *csurface;
   double cangle = 0.0, czoomx = 1.0, czoomy = 1.0;
 
   ASSERT_SURFACE (surface, 1);
@@ -740,10 +740,9 @@ turns on anti-aliasing.  */)
   IF_BOUND_ASSERT_DOUBLE_COPY (zoomy, 4);
   UNBOUND_MEANS_FALSE (smooth);
 
-  new_surface = rotozoomSurfaceXY (csurface, cangle, czoomx, czoomy,
-                                   NOT_FALSEP (smooth));
-
-  RETURN_NEW_SURFACE (new_surface);
+  RETURN_NEW_SURFACE
+    (rotozoomSurfaceXY (csurface, cangle, czoomx, czoomy,
+                        NOT_FALSEP (smooth)));
 #undef FUNC_NAME
 }
 
@@ -761,7 +760,7 @@ If omitted, @var{zoomy} defaults to @var{zoomx}.
 Optional fourth arg @var{smooth} turns on anti-aliasing.  */)
 {
 #define FUNC_NAME s_zoom_surface
-  SDL_Surface *csurface, *new_surface;
+  SDL_Surface *csurface;
   double czoomx = 1.0, czoomy = 1.0;
 
   ASSERT_SURFACE (surface, 1);
@@ -772,9 +771,9 @@ Optional fourth arg @var{smooth} turns on anti-aliasing.  */)
   IF_BOUND_ASSERT_DOUBLE_COPY (zoomy, 3);
   UNBOUND_MEANS_FALSE (smooth);
 
-  new_surface = zoomSurface (csurface, czoomx, czoomy, NOT_FALSEP (smooth));
-
-  RETURN_NEW_SURFACE (new_surface);
+  RETURN_NEW_SURFACE
+    (zoomSurface (csurface, czoomx, czoomy,
+                  NOT_FALSEP (smooth)));
 #undef FUNC_NAME
 }
 
@@ -794,7 +793,7 @@ The returned surface is antialiased by ``averaging the source
 box RGBA or Y information'' and is in 32-bit RGBA format.  */)
 {
 #define FUNC_NAME s_shrink_surface
-  SDL_Surface *csurface, *new_surface;
+  SDL_Surface *csurface;
   unsigned int cfactorx, cfactory;
 
   ASSERT_SURFACE (surface, 1);
@@ -806,9 +805,8 @@ box RGBA or Y information'' and is in 32-bit RGBA format.  */)
   ASSERT_NUMBER (factory, 3);
   cfactory = C_ULONG (factory);
 
-  new_surface = shrinkSurface (csurface, cfactorx, cfactory);
-
-  RETURN_NEW_SURFACE (new_surface);
+  RETURN_NEW_SURFACE
+    (shrinkSurface (csurface, cfactorx, cfactory));
 #undef FUNC_NAME
 }
 
@@ -818,7 +816,7 @@ box RGBA or Y information'' and is in 32-bit RGBA format.  */)
  * framerate
  */
 
-#include "SDL_gfx/SDL_framerate.h"
+#include "SDL_framerate.h"
 
 static smob_tag_t fpsmgr_tag;
 
@@ -937,7 +935,7 @@ Request an appropriate delay from FPS manager @var{mgr}.  */)
  * RGBA extras
  */
 
-#include "SDL_gfx/SDL_gfxBlitFunc.h"
+#include "SDL_gfxBlitFunc.h"
 
 
 PRIMPROC
@@ -991,7 +989,7 @@ may be relaxed in the future.  */)
  * image filter
  */
 
-#include "SDL_gfx/SDL_imageFilter.h"
+#include "SDL_imageFilter.h"
 
 PRIMPROC
 (imfi_mmx_p, "imfi-mmx?", 0, 1, 0,
